@@ -177,6 +177,21 @@ module Octokit
       end
       alias :delete_repo :delete_repository
 
+      # Transfer repository
+      #
+      # Transfer a repository owned by your organization
+      #
+      # @see https://developer.github.com/v3/repos/#transfer-a-repository
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository
+      # @param new_owner [String] The username or organization name the repository will be transferred to.
+      # @param options [Array<Integer>] :team_ids ID of the team or teams to add to the repository. Teams can only be added to organization-owned repositories.
+      # @return [Sawyer::Resource] Repository info for the transferred repository
+      def transfer_repository(repo, new_owner, options = {})
+        options = ensure_api_media_type(:transfer_repository, options)
+        post "#{Repository.path repo}/transfer", options.merge({ new_owner: new_owner })
+      end
+      alias :transfer_repo :transfer_repository
+
       # Hide a public repository
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository
@@ -380,6 +395,39 @@ module Octokit
       alias :repo_teams :repository_teams
       alias :teams :repository_teams
 
+      # List all topics for a repository
+      #
+      # Requires authenticated client for private repos.
+      #
+      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
+      # @return [Sawyer::Resource] representing the topics for given repo
+      # @see https://developer.github.com/v3/repos/#list-all-topics-for-a-repository
+      # @example List topics for octokit/octokit.rb
+      #   Octokit.topics('octokit/octokit.rb')
+      # @example List topics for octokit/octokit.rb
+      #   client.topics('octokit/octokit.rb')      
+      def topics(repo, options = {})
+        opts = ensure_api_media_type(:topics, options)
+        paginate "#{Repository.path repo}/topics", opts
+      end
+
+      # Replace all topics for a repository
+      #
+      # Requires authenticated client.
+      #
+      # @param repo [Integer, String, Repository, Hash] A Github repository
+      # @param names [Array] An array of topics to add to the repository.
+      # @return [Sawyer::Resource] representing the replaced topics for given repo
+      # @see https://developer.github.com/v3/repos/#replace-all-topics-for-a-repository
+      # @example Replace topics for octokit/octokit.rb
+      #   client.replace_all_topics('octokit/octokit.rb', ['octocat', 'atom', 'electron', 'API'])
+      # @example Clear all topics for octokit/octokit.rb
+      #   client.replace_all_topics('octokit/octokit.rb', [])
+      def replace_all_topics(repo, names, options = {})
+        opts = ensure_api_media_type(:topics, options)
+        put "#{Repository.path repo}/topics", opts.merge(:names => names)
+      end
+
       # List contributors to a repo
       #
       # Requires authenticated client for private repos.
